// keyval.inc rearranged for tisdcc

#ifndef __TI83PKEYVAL_H__
#define __TI83PKEYVAL_H__

#ifdef TI83P

// #########################################
// ## "All the Keys v1.0" by John Wyrwas  ##
// ##       20002016 - 20002019           ##
// #########################################
//
// Includes the Getkey keys values, Getcsc (getk), and Direct Input 
// key values.  They start with Gk, G, and K respectively and most contain
// the writing on the key.
//
// To use, unzip in your tasm directory and use #include keyval.inc 
//
//
// _FPRecip          4096h
// _FPSquare          4081h
// _FPSub                 406Fh

// #################
// ## Getkey Keys ##
// #################
// (the TI-OS does NOT recognize values from lowercase letter input- all are 0FC)
//
//Numbers
#define Gk0		 0x8E
#define Gk1		 0x8F
#define Gk2		 0x90
#define Gk3		 0x91
#define Gk4		 0x92
#define Gk5		 0x93
#define Gk6		 0x94
#define Gk7		 0x95
#define Gk8		 0x96
#define Gk9		 0x97
// Uppercase Letters
#define GkA		 0x9A
#define GkB		 0x9B
#define GkC		 0x9C
#define GkD		 0x9D
#define GkE		 0x9E
#define GkF		 0x9F
#define GkG		 0xA0
#define GkH		 0xA1
#define GkI		 0xA2
#define GkJ		 0xA3
#define GkK		 0xA4
#define GkL		 0xA5
#define GkM		 0xA6
#define GkN		 0xA7
#define GkO		 0xA8
#define GkP		 0xA9
#define GkQ		 0xAA
#define GkR		 0xAB
#define GkS		 0xAC
#define GkT		 0xAD
#define GkU		 0xAE
#define GkV		 0xAF
#define GkW		 0xB0
#define GkX		 0xB1
#define GkY		 0xB2
#define GkZ		 0xB3
// Other Keys
#define GkMode		 0x45
#define GkIns		 0x0B
#define GkDel		 0x0A
#define GkRight		 0x01
#define GkLeft		 0x02
#define GkUp		 0x03
#define GkDown		 0x04
#define GkXTN		 0xB4
#define GkLink		 0x41
#define GkStat		 0x31
#define GkList		 0x3A
#define GkMath		 0x32
#define GkTest		 0x33
#define GkApps		 0x2C
#define GkAngle		 0x39
#define GkPrgm		 0x2D
#define GkDraw		 0x2F
#define GkVars		 0x35
#define GkDistr		 0x38
#define GkClear		 0x09
#define GkX1		 0xB6
#define GkMatrix	 0x37
#define GkSin		 0xB7
#define GkSin1		 0xB8
#define GkCos		 0xB9
#define GkCos1		 0xBA
#define GkTan		 0xBB
#define GkTan1		 0xBC
#define GkPower		 0x84
#define GkPi		 0xB5
#define GkX2		 0xBD
#define GkRoot		 0xBE
#define GkComma		 0x8B
#define GkEE		 0x98

#define GkRightPar	 0x86
#define GkLeftPar	 0x85

#define GkDivide	 0x83
#define GkMultiply	 0x82
#define GkSubtract	 0x81
#define GkAdd		 0x80
#define GkEnter		 0x05

#define GkLittleE	 0xEF
#define GkLeftBracket	 0x87
#define GkRightBracket	 0x88
#define GkMem		 0x36
#define GkEntry		 0x0D
#define GkQuotes	 0xCB
#define GkSolve		 0x05


#define GkLog		 0xC1
#define GkLn		 0xBF
#define GkSto		 0x8A
#define Gk10X		 0xC2
#define GkeX		 0xC0
#define GkRcl		 0xC

#define GkLittleU 	 0xF9
#define GkLittleV	 0xFA
#define GkLittleW	 0xFB
#define GkLittleI	 0xEE

#define GkL1		 0xF3
#define GkL2		 0xF4
#define GkL3		 0xF5
#define GkL4		 0xF6
#define GkL5		 0xF7
#define GkL6		 0xF8
 
#define GkCatalog	 0x3E
#define GkAns		 0xC5
#define GkSpace		 0x99
#define GkColon		 0xC6
#define GkQuestion	 0xCA
#define GkPeriod	 0x8D
#define GkNegative	 0x8C

#define GkF1		 0x49
#define GkF2 		 0x48
#define GkF3		 0x2E
#define GkF4		 0x5A
#define GkF5		 0x44

#define GkStatPlot	 0x30
#define GkTblset	 0x4B
#define GkFormat	 0x57
#define GkCalc		 0x3B
#define GkTable		 0x4A


//############################
//##     Getcsc/Getk Keys   ##
//############################

#define GF1		 0x35
#define GF2		 0x34
#define GF3		 0x33
#define GF4		 0x32
#define GF5		 0x31

#define G2nd		 0x36
#define GMode		 0x37
#define GDel		 0x38

#define GDown		 0x01
#define GLeft		 0x02
#define GRight		 0x03
#define GUp		 0x04

#define GAlpha		 0x30
#define GXTN		 0x28
#define GStat		 0x20
#define GMath		 0x2F
#define GApps		 0x27
#define GPrgm		 0x1F
#define GVars		 0x17
#define GClear		 0x0F
#define GX1		 0x2E
#define GSin		 0x26
#define GCos		 0x1E
#define GTan		 0x16
#define GPower		 0x0E
#define GX2		 0x2D
#define GComma 		 0x25
#define GLeftPara	 0x1D
#define GRightPara	 0x15

#define GDivide		 0x0D
#define GMultiply	 0x0C
#define GSubtract	 0x0B
#define GAdd		 0x0A
#define GEnter		 0x09
#define GLog		 0x2C
#define GLn		 0x2B
#define GSto		 0x2A

#define G0		 0x21
#define G1		 0x22
#define G2		 0x1A
#define G3		 0x12
#define G4		 0x23
#define G5		 0x1B
#define G6		 0x13
#define G7		 0x24
#define G8		 0x1C
#define G9		 0x14

#define GPeriod 	 0x8D
#define GNegative	 0x8C

//#######################
//## Direct Input Keys ##
//#######################

//Group 1
#define KeyRow_Pad	 0xfe
#define KDown		 254 
#define KLeft		 253 
#define KRight		 251 
#define KUp		 247 

//Group 2
#define KeyRow_5 	 0xfd
#define KEnter		 254 
#define KPlus		 253 
#define KMinus		 251 
#define KMul		 247 
#define KDiv		 239 
#define KPower		 223 
#define KClear		 191 

//Group 3
#define KeyRow_4 	 0xfb
#define KMinus2		 254 
#define KThree		 253 
#define KSix		 251 
#define KNine		 247 
#define KRbracket	 239 
#define KTan		 223 
#define KVars		 191 

//Group 4
#define KeyRow_3	 0xf7
#define KPoint		 254 
#define KTwo		 253 
#define KFive		 251
#define KEight		 247
#define KLbracket	 239
#define KCos		 223
#define KPrgm		 191
#define KStat		 127 

//Group 5
#define KeyRow_2 	 0xef
#define KZero		 254
#define KOne		 253
#define KFour		 251
#define KSeven		 247
#define KComma		 239
#define KSin		 223
#define KMatrx		 191
#define KX		 127 

//Group 6
#define KeyRow_1 	 0xdf
#define KSto		 253
#define KLn		 251
#define KLog		 247
#define kX2		 239
#define kX_1		 223
#define kMath		 191
#define kAlpha		 127 

//Group 7
#define KeyRow_Top 	 0xbf
#define KGraph		 254
#define KTrace		 253
#define KZoom		 251
#define KWindow		 247
#define KY		 239
#define k2nd		 223
#define kMode		 191
#define kDel		 127

#endif // of TI83P

#endif // of __TI83PKEYVAL_H__
